Module enums

Module enums 

Wrappers for libxc enums and bitflags.

Modules

libxc_enum_items
Re-export all enum items for easy access.

Structs

LIBXC_FUNC_ENUM
Full list of functional identifiers (lazily generated).
LIBXC_FUNC_MAP
Mapping from functional identifier string to number id (lazily generated).
LIBXC_FUNC_STR
Full list of functional identifiers strings (lazily generated).

Enums

LibXCDeviceFlag
Whether the functional can be evaluated on device (CUDA) or host (CPU).
LibXCFamily
The family of the functional: LDA, GGA, MGGA and its hybrid variants.
LibXCFlags
Bitflags for functional properties.
LibXCFuncId
The functional identifier type, which is alias of FFI enum XcFuncId.
LibXCFunctionalKind
The kind of the functional: exchange, correlation, exchange-correlation, or kinetic.
LibXCRelavistic
Whether the functional is relativistic or non-relativistic.
LibXCSpin
Spin polarization of the functional.